@@ -176,4 +176,16 @@ class Tag(object):
         getEnv().dashboard.job.cache({'TAG': {key: value}})
 
 
-tag = Tag()
\ No newline at end of file
+tag = Tag()
+
+
+class Info(object):
+    def __init__(self):
+        pass
+
+    def __getattr__(self, key):
+        if getEnv().dashboard is not None:
+            return getattr(getEnv().dashboard, key)
+
+
+info = Info()
\ No newline at end of file
